@@ -11,4 +11,4 @@ class Error:
     filename: Optional[str] = None
 
     def __str__(self) -> str:
-        return f"{self.filename}:{self.line}:{self.column} [FURB{self.code}]: {self.msg}"  # noqa
+        return f"{self.filename}:{self.line}:{self.column + 1} [FURB{self.code}]: {self.msg}"  # noqa
